

# Install MariaDB and create empty StoRM databases
class { 'storm::db':
    override_options => {
        'mysqld' => {
            'bind-address'    => '0.0.0.0',
            'max_connections' => 4000,
        },
    },
}

# Install and configure StoRM Backend
class { 'storm::backend':
  require                      => Accounts::User['storm'],
  hostname                     => 'storm-lhcb.cr.cnaf.infn.it',
  db_username                  => 'storm',
  db_password                  => 'storm',
  install_native_libs_gpfs     => true,
  xmlrpc_security_token        => 'STRINGALHCB',
  frontend_public_host         => 'storm-fe-lhcb.cr.cnaf.infn.it',
  srm_pool_members             => [
      {
          'hostname' => 'storm-lhcb.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'storm-fe-lhcb.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'storm-fe-lhcb-03.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'storm-fe-lhcb-04.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'storm-lhcb-disk.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'storm-lhcb-tape.cr.cnaf.infn.it',
      },
  ],
  gsiftp_pool_balance_strategy => 'smart-rr',
  gsiftp_pool_members          => [
      {
          'hostname' => 'xs-101.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'xs-102.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'xs-103.cr.cnaf.infn.it',
      },
      {
          'hostname' => 'xs-104.cr.cnaf.infn.it',
      },
  ],
  info_sitename                => 'INFN-T1',
  info_endpoint_quality_level  => 3,
  xroot_hostname               => 'xrootd-lhcb.cr.cnaf.infn.it',
  storage_areas                => [
    {
      'name'               => 'lhcb_disk',
      'root_path'          => '/storage/gpfs_lhcb/lhcb/disk',
      'access_points'      => ['/disk/lhcb', '/t0d1/lhcb', '/t1d1/lhcb'],
      'vos'                => ['lhcb'],
      'fs_type'            => 'gpfs',
      'storage_class'      => 'T0D1',
      'online_size'        => 2284000,
      'transfer_protocols' => ['file', 'gsiftp', 'xroot'],
      'acl_mode'           => 'AoT',
      'space_token'        => 'LHCb-Disk',
      'default_acl_list'   => [
        {
          group      => 'lhcb',
          permission => 'R',
        },
      ],
      'quota'              => {
        device => 'gpfs_lhcb',
        type   => 'fileset',
        value  => 'LHCb-Disk',
      },
    },
    {
      'name'               => 'lhcb_tape',
      'root_path'          => '/storage/gpfs_lhcb/lhcb/tape',
      'access_points'      => ['/tape/lhcb', '/t1d0/lhcb'],
      'vos'                => ['lhcb'],
      'fs_type'            => 'gpfs',
      'storage_class'      => 'T1D0',
      'online_size'        => 2537294,
      'nearline_size'      => 166912,
      'transfer_protocols' => ['file', 'gsiftp', 'xroot'],
      'acl_mode'           => 'AoT',
      'space_token'        => 'LHCb-Tape',
      'default_acl_list'   => [
        {
          group      => 'lhcb',
          permission => 'R',
        },
      ],
    },
    {
      'name'               => 'lhcb_user',
      'root_path'          => '/storage/gpfs_lhcb/lhcb/user',
      'access_points'      => ['/t0d1/lhcb/user', '/disk/lhcb/user'],
      'vos'                => ['lhcb'],
      'fs_type'            => 'gpfs',
      'storage_class'      => 'T0D1',
      'online_size'        => 121000,
      'transfer_protocols' => ['file', 'gsiftp', 'xroot'],
      'acl_mode'           => 'AoT',
      'space_token'        => 'LHCb_USER',
      'default_acl_list'   => [
        {
          group      => 'lhcb',
          permission => 'R',
        },
      ],
      'quota'              => {
        device => 'gpfs_lhcb',
        type   => 'fileset',
        value  => 'LHCb_USER',
      },
    },
    {
      'name'               => 'dteam',
      'root_path'          => '/storage/gpfs_lhcb/dteam',
      'access_points'      => ['/dteam'],
      'vos'                => ['dteam'],
      'fs_type'            => 'gpfs',
      'storage_class'      => 'T0D1',
      'online_size'        => 1,
      'transfer_protocols' => ['file', 'gsiftp','xroot'],
      'acl_mode'           => 'AoT',
      'quota'              => {
        device => 'gpfs_lhcb',
        type   => 'fileset',
        value  => 'Dteam',
      },
    },
    {
      'name'               => 'ops',
      'root_path'          => '/storage/gpfs_lhcb/ops',
      'access_points'      => ['/ops'],
      'vos'                => ['ops'],
      'fs_type'            => 'gpfs',
      'storage_class'      => 'T0D1',
      'online_size'        => 1,
      'transfer_protocols' => ['file', 'gsiftp','xroot'],
      'acl_mode'           => 'AoT',
      'quota'              => {
        device => 'gpfs_lhcb',
        type   => 'fileset',
        value  => 'Ops',
      },
    },
    {
      'name'               => 'info',
      'root_path'          => '/storage/gpfs_lhcb/info',
      'access_points'      => ['/info'],
      'vos'                => ['dteam', 'ops', 'lhcb'],
      'fs_type'            => 'gpfs',
      'storage_class'      => 'T0D1',
      'online_size'        => 1,
      'transfer_protocols' => ['file', 'gsiftp','webdav'],
    },
  ],
}

# Install and configure BDII service
class { 'bdii':
    firewall   => false,
    bdiipasswd => 'STRINGABDII',
}

# StoRM Backend's path-authz.db file
file { '/etc/storm/backend-server/path-authz.db':
  ensure  => present,
  mode    => '0644',
  owner   => 'storm',
  group   => 'storm',
  source  => 'puppet:///modules/storage_storm_endpoint/backend_conf/path-authz_lhcb.db',
  require => [Class['storm::backend']],
  notify  => [Service['storm-backend-server']],
}

# dbspace script directory
file { '/root/DBSPACE':
  ensure => directory,
  owner  => 'root',
  group  => 'root',
  mode   => '0755',
}
# dbspace script file
file { '/root/DBSPACE/dbspace.sh':
  ensure  => present,
  owner   => 'root',
  group   => 'root',
  mode    => '0755',
  require => File['/root/DBSPACE'],
  source  => 'puppet:///modules/storage_storm_endpoint/backend_conf/dbspace_lhcb.sh',
}
# dbspace script cron job
cron { 'dbspace.cron':
  command => '/root/DBSPACE/dbspace.sh >> /root/DBSPACE/dbspace.log 2>&1',
  user    => 'root',
  minute  => '*/5',
  require => [Class['storm::backend'], File['/root/DBSPACE/dbspace.sh']],
}

# Storage Site Report script
file { '/root/update-site-report.sh':
  ensure => 'present',
  source => 'puppet:///modules/storm/update-site-report.sh',
}
# Storage Site Report cron
cron { 'update-site-report':
  ensure  => 'present',
  command => '/bin/bash /root/update-report.sh',
  user    => 'root',
  minute  => '*/30',
  require => [Class['storm::backend'], File['/root/update-site-report.sh']],
}
# Storage Site Report execution
exec { 'create-site-report':
  command => '/bin/bash /root/update-site-report.sh',
  require => [Class['storm::backend'], File['/root/update-site-report.sh']],
}

# order
Class['storm::db']
-> Class['storm::backend']
-> Class['bdii']
